@@ -1,26 +1,45 @@
+"""OeREB Client Package."""
 # -*- coding: utf-8 -*-
-import yaml
+import os
+import logging
+from pyaml_env import parse_config
 from pyramid.config import Configurator
 from pyramid_mako import add_mako_renderer
 
 
-__version__ = '1.3.8'
+__version__ = '2.0.0'
+
+
+log = logging.getLogger('oereb_client')
 
 
 def main(global_config, **settings):  # pragma: no cover
     """
-    This function returns a Pyramid WSGI application. This is necessary for development of
-    your plugin. So you can run it local with the paster server and in a IDE like PyCharm. It
-    is intended to leave this section as is and do configuration in the includeme section only.
-    Push additional configuration in this section means it will not be used by the production
-    environment at all!
+    This function returns a Pyramid WSGI application.
+
+    This is necessary for development of your plugin or if the application
+    is run in a container. It is intended to leave this section as is and
+    do configuration in the includeme section only.
     """
-    with open('oereb_client.yml') as f:
-        yml = yaml.safe_load(f.read())
+    if 'LOG_LEVEL' in os.environ:
+        log_level = '{0}'.format(os.environ.get('LOG_LEVEL')).lower()
+        if log_level in ['error', 'err']:
+            log.setLevel(logging.ERROR)
+        elif log_level in ['warning', 'warn']:
+            log.setLevel(logging.WARNING)
+        elif log_level in ['debug', 'dev', 'development']:
+            log.setLevel(logging.DEBUG)
+
+    yml = parse_config(settings.get('config'))
     settings.update(yml)
+
     config = Configurator(settings=settings)
     config.include('oereb_client')
-    config.include('samples')
+
+    if os.environ.get('DEVELOPMENT') == 'true':
+        config.include('samples')
+        log.info('RUNNING IN DEVELOPMENT MODE!')
+
     config.scan()
     return config.make_wsgi_app()
 
@@ -31,9 +50,6 @@ def includeme(config):  # pragma: no cover
     :param config: The configurator object from the including pyramid module.
     :type geometries: Configurator
     """
-    # If you need access to the settings in this part, you can get them via
-    # settings = config.get_settings()
-    global route_prefix
 
     config.include('pyramid_mako')
 
